@@ -548,15 +548,12 @@ class AyatanaWebmail(object):
         elif self.bNoNetwork:
 
             self.bNoNetwork = False
+            self.bIdlerRunning = True
 
-            if not self.bIdlerRunning:
+            for oConnection in self.lstConnections:
+                oConnection.bConnecting = True
 
-                self.bIdlerRunning = True
-
-                for oConnection in self.lstConnections:
-                    oConnection.bConnecting = True
-
-                GLib.timeout_add_seconds(5, self.connect, self.lstConnections)
+            GLib.timeout_add_seconds(5, self.connect, self.lstConnections)
 
         return True
 
@@ -873,7 +870,7 @@ class AyatanaWebmail(object):
             thread_id = ''
             msg = None
 
-            try:
+            if any(s in oConnection.strHost for s in ['gmail', 'google']):
 
                 typ, msg_data = oConnection.oImap.uid('FETCH', m, '(X-GM-THRID BODY.PEEK[HEADER.FIELDS (DATE SUBJECT FROM MESSAGE-ID)])')
 
@@ -884,7 +881,7 @@ class AyatanaWebmail(object):
                         thread_id = '%x' % int(m_reThrid.search(lstField[0]).group(1))
                         break
 
-            except imaplib.IMAP4.error:
+            else:
 
                 typ, msg_data = oConnection.oImap.uid('FETCH', m, '(BODY.PEEK[HEADER.FIELDS (DATE SUBJECT FROM MESSAGE-ID)])')
 
@@ -1081,33 +1078,36 @@ class AyatanaWebmail(object):
         logger.info('Checking network...')
 
         if not checkNetwork():
+
             return False
 
-        logger.info('Network connection active, connecting...')
+        if (lstConnections):
 
-        for oConnection in lstConnections:
+            logger.info('Network connection active, connecting...')
 
-            oConnection.close()
+            for oConnection in lstConnections:
 
-            try:
+                oConnection.close()
 
-                oConnection.connect()
-                oConnection.bConnecting = False
+                try:
 
-            except KeyboardInterrupt:
+                    oConnection.connect()
+                    oConnection.bConnecting = False
 
-                self.close(0)
+                except KeyboardInterrupt:
 
-            except Exception as oException:
+                    self.close(0)
 
-                logger.error('"{0}:{1}" could not connect: {2}'.format(oConnection.strLogin, oConnection.strFolder, str(oException)))
+                except Exception as oException:
 
-                oNotification = Notify.Notification.new(_('Connection error'), '', APPNAME)
-                oNotification.set_property('body', _('Unable to connect to account "{accountName}", the application will now exit.').format(accountName=oConnection.strLogin))
-                oNotification.set_hint('desktop-entry', GLib.Variant.new_string(APPNAME))
-                oNotification.set_timeout(Notify.EXPIRES_NEVER)
-                oNotification.show()
-                self.close(1)
+                    logger.error('"{0}:{1}" could not connect: {2}'.format(oConnection.strLogin, oConnection.strFolder, str(oException)))
+
+                    oNotification = Notify.Notification.new(_('Connection error'), '', APPNAME)
+                    oNotification.set_property('body', _('Unable to connect to account "{accountName}", the application will now exit.').format(accountName=oConnection.strLogin))
+                    oNotification.set_hint('desktop-entry', GLib.Variant.new_string(APPNAME))
+                    oNotification.set_timeout(Notify.EXPIRES_NEVER)
+                    oNotification.show()
+                    self.close(1)
 
         return False
 
